==> camitk_5.1.0.orig.tar.gz: CamiTK-5.1.0/sdk/actions/image/arbitraryslice/ArbitrarySliceExtension.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2023 Univ. Grenoble Alpes, CNRS, Grenoble INP, TIMC, 38000 Grenoble, France
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/
#ifndef ARBITRARYSLICEEXTENSION_H
#define ARBITRARYSLICEEXTENSION_H

#include <ActionExtension.h>

/**
 * @ingroup group_sdk_actions_image_arbitraryslice
 *
 * @brief
 * The arbitrary slice action extension.
 */
class ArbitrarySliceExtension : public camitk::ActionExtension {
    Q_OBJECT
    Q_INTERFACES(camitk::ActionExtension)
    Q_PLUGIN_METADATA(IID "fr.imag.camitk.sdk.action.arbitraryslice")

public:
    /// Constructor
    ArbitrarySliceExtension() : ActionExtension() {};

    /// Destructor
    virtual ~ArbitrarySliceExtension() = default;

    /// Method returning the action extension name
    virtual QString getName() override {
        return "ArbitrarySliceExtension";
    };

    /// Method returning the action extension description
    virtual QString getDescription() override {
        return "This extension gathers actions for manipulating the arbitrary slice in a 3D image.";
    };

    /// initialize all the actions
    virtual void init() override;

};

#endif // ARBITRARYSLICEEXTENSION_H

==> camitk_5.2.0.orig.tar.gz: CamiTK-5.2.0/sdk/actions/image/arbitraryslice/ArbitrarySliceExtension.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2024 Univ. Grenoble Alpes, CNRS, Grenoble INP - UGA, TIMC, 38000 Grenoble, France
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/
#ifndef ARBITRARYSLICEEXTENSION_H
#define ARBITRARYSLICEEXTENSION_H

#include <ActionExtension.h>

/**
 * @ingroup group_sdk_actions_image_arbitraryslice
 *
 * @brief
 * The arbitrary slice action extension.
 */
class ArbitrarySliceExtension : public camitk::ActionExtension {
    Q_OBJECT
    Q_INTERFACES(camitk::ActionExtension)
    Q_PLUGIN_METADATA(IID "fr.imag.camitk.sdk.action.arbitraryslice")

public:
    /// Constructor
    ArbitrarySliceExtension() : ActionExtension() {};

    /// Destructor
    virtual ~ArbitrarySliceExtension() = default;

    /// Method returning the action extension name
    virtual QString getName() override {
        return "Arbitrary Slice";
    };

    /// Method returning the action extension description
    virtual QString getDescription() override {
        return "This extension gathers actions for manipulating the arbitrary slice in a 3D image.";
    };

    /// initialize all the actions
    virtual void init() override;

};

#endif // ARBITRARYSLICEEXTENSION_H
